@@ -16,7 +16,7 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 #
-#   Version v.0.1
+#   Version v0.1.1
 
 import itertools
 import base64
@@ -26,6 +26,7 @@ from BinaryParser import *
 
 indent = ""
 
+
 class SYSTEM_TOKENS:
     EndOfStreamToken = 0x00
     OpenStartElementToken = 0x01
@@ -134,7 +135,7 @@ class BXmlNode(Block):
             (self)
 
     def verify(self):
-        return true
+        return True
 
     def _children(self, max_children=None,
                   end_tokens=[SYSTEM_TOKENS.EndOfStreamToken]):
@@ -277,6 +278,7 @@ class TemplateNode(BXmlNode):
     def length(self):
         return self.tag_length() + self.data_length()
 
+
 class EndOfStreamNode(BXmlNode):
     """
     The binary XML node for the system token 0x00.
@@ -311,6 +313,7 @@ class EndOfStreamNode(BXmlNode):
     def children(self):
         return []
 
+
 class OpenStartElementNode(BXmlNode):
     """
     The binary XML node for the system token 0x01.
@@ -394,8 +397,21 @@ class OpenStartElementNode(BXmlNode):
         if (self.is_empty_node() or num_active_children == 0) \
                 and has_attr_xml:
             return "\n<%s%s />" % (self.tag_name(), attr_xml)
-        else: # num_active_children != 0 and has_attr_xml
-            cxml = "".join(c.xml(substitutions) for c in self.children())
+        else:  # num_active_children != 0 and has_attr_xml
+            try:
+                cxml = "".join(c.xml(substitutions).decode("utf-8") for c in self.children())
+            except UnicodeEncodeError as e:
+                # somewhere, unicode vs raw strings are getting mixed up.
+                #  here's a hacky fix.
+                cxml = ""
+                for c in self.children():
+                    try:
+                        cxml += c.xml(substitutions).encode("utf-8")
+                    except UnicodeEncodeError as f:
+                        raise f
+                return cxml
+            except UnicodeDecodeError as e:
+                raise e
             return "\n<%s%s</%s>" % (self.tag_name(), cxml, self.tag_name())
 
     def template_format(self):
@@ -918,6 +934,10 @@ class TemplateInstanceNode(BXmlNode):
         template = self._chunk.templates()[self.template_offset()]
         return template.xml(substitutions)
 
+    def template_format(self):
+        template = self._chunk.templates()[self.template_offset()]
+        return template.template_format()
+
     def is_resident_template(self):
         return self.template_offset() > self.offset() - self._chunk._offset
 
@@ -1109,6 +1129,12 @@ class RootNode(BXmlNode):
             cxml += child.xml(substitutions or self.substitutions())
         return cxml
 
+    def template_format(self):
+        ret = []
+        for child in self.children():
+            ret.append(child.template_format())
+        return "".join(ret)
+
     def tag_length(self):
         return 0
 
@@ -1258,22 +1284,22 @@ class WstringTypeNode(VariantTypeNode):
                                               parent, length=length)
         if self._length is None:
             self.declare_field("word",    "string_length", 0x0)
-            self.declare_field("wstring", "string",
+            self.declare_field("wstring", "_string",
                                length=(self.string_length()))
         else:
-            self.declare_field("wstring", "string", 0x0,
+            self.declare_field("wstring", "_string", 0x0,
                                length=(self._length / 2))
 
     def xml(self):
         # ensure this is a str, not unicode
         try:
-            return str(self.string())
+            return str(self.string().replace("<", "&gt;").replace(">", "&lt;"))
         except UnicodeEncodeError:
             try:
-                return self.string().encode("ascii", "xmlcharrefreplace")
+                return self.string().encode("utf-8", "xmlcharrefreplace").replace("<", "&gt;").replace(">", "&lt;")
             except (UnicodeEncodeError, UnicodeDecodeError) as e:
                 debug("E", "%r" % (self), e)
-                return str(self.string())
+                return str(self.string().replace("<", "&gt;").replace(">", "&lt;"))
 
     def template_format(self):
         return self.xml([])
@@ -1283,6 +1309,9 @@ class WstringTypeNode(VariantTypeNode):
             return (2 + (self.string_length() * 2))
         return self._length
 
+    def string(self):
+        return self._string().rstrip("\x00")
+
 
 class StringTypeNode(VariantTypeNode):
     """
@@ -1294,13 +1323,13 @@ class StringTypeNode(VariantTypeNode):
                                              parent, length=length)
         if self._length is None:
             self.declare_field("word",   "string_length", 0x0)
-            self.declare_field("string", "string",
+            self.declare_field("string", "_string",
                                length=(self.string_length()))
         else:
-            self.declare_field("string", "string", 0x0, length=self._length)
+            self.declare_field("string", "_string", 0x0, length=self._length)
 
     def xml(self):
-        return str(self.string())
+        return str(self.string().replace("<", "&gt;").replace(">", "&lt;"))
 
     def template_format(self):
         return self.xml([])
@@ -1310,6 +1339,9 @@ class StringTypeNode(VariantTypeNode):
             return (2 + (self.string_length()))
         return self._length
 
+    def string(self):
+        return self._string().rstrip("\x00")
+
 
 class SignedByteTypeNode(VariantTypeNode):
     """
@@ -1842,13 +1874,18 @@ class WstringArrayTypeNode(VariantTypeNode):
         for apart in bin.split("\x00\x00\x00"):
             for bpart in apart.split("\x00\x00"):
                 if len(bpart) % 2 == 1:
-                    strings.append(bpart + "\x00")
+                    strings.append((bpart + "\x00").decode("utf-16"))
                 else:
-                    strings.append(bpart)
+                    strings.append(bpart.decode("utf-16"))
         if strings[-1].strip("\x00") == "":
             strings = strings[:-1]
-        for (i, string) in enumerate(strings):
-            ret += "[%d] %s\n" % (i, string.decode("utf-16"))
+        for (index, string) in enumerate(strings):
+            if string == "":
+                ret += "<string index=\"%d\" isNull=\"True\" />\n" % \
+                    (index)
+            else:
+                ret += "<string index=\"%d\">%s</string>\n" % \
+                    (index, string.rstrip("\x00"))
         return ret
 
     def template_format(self):
